from setuptools import setup

setup(
    name ='poiebot',
    version = '1.0.3',
    description = 'poiebot',
    author = 'pb',
    author_email = 'poiega@poie.ga',
    url = None,
    py_modules = ['poiebot'] 
)
